@@ -15,6 +15,9 @@ from app import models
 import threading
 import requests
 import base64
+import serial
+import serial.tools.list_ports
+import platform
 
 
 # Create your views here.
@@ -29,46 +32,6 @@ def upfile(request):
     f.close()
     return HttpResponse('ok')
 
-def cmd_msg(request):
-    datas=models.MxpiArticles.objects.filter(read=0)
-    if len(datas)>0:
-        datas[0].read=1
-        datas[0].save()
-        print(datas[0].body)
-        return HttpResponse(datas[0].body)
-    else:
-        return HttpResponse('cmd')
-
-def run_cmd(request):
-    models.MxpiArticles.objects.filter(title='cmd').delete()
-    p = subprocess.Popen('python -u file/test.py', shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT,bufsize=1)
-    while p.poll() is None:
-            #sys.stdout.flush()
-            line = p.stdout.readline().strip()
-            if line:
-                line = _decode_data(line)
-                print(line)
-                #s=myThread(line)
-                #s.start()
-    return HttpResponse('ok')
-
-class myThread (threading.Thread):
-    def __init__(self, line):
-        threading.Thread.__init__(self)
-        self.line = line
-    def run(self):
-        models.MxpiArticles.objects.create(title='cmd',body=self.line,read=False)
-
-def _decode_data(byte_data: bytes):
-    """
-    解码数据
-    :param byte_data: 待解码数据
-    :return: 解码字符串
-    """
-    try:
-        return byte_data.decode('UTF-8')
-    except UnicodeDecodeError:
-        return byte_data.decode('GB18030')
 
 def file_list(request):
     url_=os.path.dirname(mxpi.__file__).replace('\\','/')
@@ -114,7 +77,7 @@ def files(request):
 def get_c(request):
     try:
         name=request.GET.get('name')
-        file='example/'+name+'.mxpi'
+        file=os.path.dirname(mxpi.__file__)+'/example/'+name+'.mxpi'
         print(file)
         if os.path.exists(file):
             f=open(file,'r',encoding='utf-8')
@@ -156,3 +119,43 @@ def downModel(request):
         f.write(r.content)
         f.close
     return HttpResponse('ok')    
+
+def SArduino_get_list(request):
+    if platform.system()=='Windows':
+        ports = serial.tools.list_ports.comports(include_links=False)
+        spp=[]
+        for port, desc, hwid in sorted(ports):
+            sp={
+                'port':port,
+                'desc':desc,
+            }
+            spp.append(sp)
+        return HttpResponse(json.dumps({'msg':'ok','data':spp}))
+    else:
+        return HttpResponse(json.dumps({'msg':'err','data':'目前SArduino只支持Windows,你目前的系统为'+platform.system()}))
+
+def SArduino_add_data(request):
+    data=request.GET.get('data')
+    all_in_data=models.Mxpi_SArduino_in.objects.all()
+    if len(all_in_data)>10:
+        all_in_data.last().delete()
+    s=models.Mxpi_SArduino_in()
+    s.data=data
+    s.save()
+    return HttpResponse(json.dumps({'msg':'ok','data':''}))
+
+def SArduino_get_data(request):
+    all_in_data=models.Mxpi_SArduino_in.objects.all()
+    p=all_in_data.first()
+    return HttpResponse(p.data)
+
+def mixly_ku_download(request):
+    file_path=os.path.dirname(mxpi.__file__)+'/file/SArduino-com.zip'
+    with open(file_path, 'rb') as f:
+        try:
+            response = HttpResponse(f)
+            response['content_type'] = "application/octet-stream"
+            response['Content-Disposition'] = 'attachment; filename=' + os.path.basename(file_path)
+            return response
+        except:
+            pass
