@@ -70,6 +70,9 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'SArduino_category': {
         'colour': "#fb7b04",
       },
+      'UNIHIKER_category': {
+        'colour': "#3f54f3",
+      },
       'GUI_category': {
         'colour': "#00a8a8",
       },
@@ -127,6 +130,11 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'colourSecondary':"#fff",
       'colourTertiary':"#fb7b04"
     }, 
+    'UNIHIKER_blocks': {
+      'colourPrimary': "#3f54f3",
+      'colourSecondary':"#fff",
+      'colourTertiary':"#3f54f3"
+    }, 
     'sensor_blocks': {
       'colourPrimary': "#bc954e",
       'colourSecondary':"#fff",
