@@ -1,5 +1,6 @@
 
 var pin =  [["0", "0"], ["1", "1"], ["2", "2"], ["3", "3"], ["4", "4"], ["5", "5"], ["6", "6"], ["7", "7"], ["8", "8"], ["9", "9"], ["10", "10"], ["11", "11"], ["12", "12"], ["13", "13"], ["14", "14"], ["15", "15"], ["16", "16"], ["17", "17"], ["18", "18"], ["19", "19"], ["20", "20"], ["21", "21"], ["26", "26"], ["33", "33"], ["34", "34"], ["35", "35"], ["36", "36"], ["37", "37"], ["38", "38"], ["39", "39"], ["40", "40"]];
+var pin_ad=[["A0","A0"],["A1","A2"],["A3","A3"],["A4","A4"]]
 
 Blockly.Blocks['pins'] = {
     init: function() {
@@ -10,6 +11,15 @@ Blockly.Blocks['pins'] = {
    }
    };
 
+   Blockly.Blocks['pins_ad'] = {
+    init: function() {
+     this.setColour(90);
+     this.appendDummyInput("")
+     .appendField(new Blockly.FieldDropdown(pin_ad), 'PIN');
+     this.setOutput(true, Number);
+   }
+   };
+
 Blockly.Blocks['inout_highlow'] = {
 init: function() {
     this.setColour(90);
@@ -108,7 +118,53 @@ Blockly.Blocks['GPIO_model'] = {
         }
   };
 
+  Blockly.Blocks.GPIO_AD_IN= {
+    init: function() {
+    this.appendDummyInput()
+        .appendField("模拟");
+    this.appendValueInput("NAME")
+        .setCheck(null);
+    this.appendDummyInput()
+        .appendField("输入 引脚 #");
+    this.appendValueInput("PIN")
+        .setCheck(null);
+    this.setInputsInline(true);
+    this.setOutput(true, null);
+    this.setStyle('GPIO_blocks');
+    this.setTooltip("读取模拟引脚的值");
+    this.setHelpUrl("");
+    }
+  };
 
+  Blockly.Blocks.GPIO_AD_init= {
+    init: function() {
+    this.appendDummyInput()
+        .appendField("PCF8591数模转换模块初始化");
+    this.setInputsInline(true);
+    this.setOutput(true, null);
+    this.setStyle('GPIO_blocks');
+    this.setTooltip("初始化PCF8591数模转换模块");
+    this.setHelpUrl("");
+    }
+  };
+
+  Blockly.Blocks.GPIO_AD_OUT= {
+    init: function() {
+    this.appendDummyInput()
+        .appendField("模拟");
+    this.appendValueInput("NAME")
+        .setCheck(null);
+    this.appendValueInput("VAR")
+        .setCheck(null)
+        .appendField("输出值");
+    this.setInputsInline(true);
+    this.setPreviousStatement(true, null);
+    this.setNextStatement(true, null);
+    this.setStyle('GPIO_blocks');
+    this.setTooltip("模拟引脚输出值");
+    this.setHelpUrl("");
+    }
+  };
   Blockly.Blocks.GPIO_pwm_init= {
     init: function() {
     this.appendValueInput("PIN")
