@@ -131,6 +131,21 @@ Blockly.Blocks.python_opencv_imread= {
     }
   };
 
+  Blockly.Blocks.python_opencv_rotating= {
+    init: function() {
+    this.appendValueInput("NAME")
+        .setCheck(null)
+        .appendField("图像");
+    this.appendDummyInput()
+        .appendField(" 顺时针旋转")
+        .appendField(new Blockly.FieldDropdown([["90°","90"],["180°","180"],["270°","270"]]), "NUM");
+    this.setInputsInline(true);
+    this.setOutput(true, null);
+    this.setStyle('OpenCV_blocks');
+    this.setTooltip("顺时针旋转图像");
+    this.setHelpUrl("");
+    }
+  };
 
   Blockly.Blocks.python_opencv_color_block= {
     init: function() {
@@ -185,6 +200,28 @@ Blockly.Blocks.python_opencv_imread= {
     this.setHelpUrl("");
     }
   };
+
+  Blockly.Blocks.python_opencv_cap_setHW= {
+    init: function() {
+    this.appendValueInput("NAME")
+        .setCheck(null)
+        .appendField("设置摄像头");
+    this.appendDummyInput()
+        .appendField("图像");
+    this.appendValueInput("W")
+        .setCheck(null)
+        .appendField("宽度");
+    this.appendValueInput("H")
+        .setCheck(null)
+        .appendField("高度");
+    this.setInputsInline(true);
+    this.setPreviousStatement(true, null);
+    this.setNextStatement(true, null);
+    this.setStyle('OpenCV_blocks');
+    this.setTooltip("设置摄像头获取的图像宽高");
+    this.setHelpUrl("");
+    }
+  };
   
   Blockly.Blocks.python_opencv_readcam= {
     init: function() {
@@ -290,4 +327,21 @@ Blockly.Blocks.python_opencv_imread= {
     this.setTooltip("在图像上绘制文字");
     this.setHelpUrl("");
     }
-  };
\ No newline at end of file
+  };
+
+
+  Blockly.Blocks.python_opencv_FULLSCREEN= {
+    init: function() {
+    this.appendValueInput("NAME")
+        .setCheck(null)
+        .appendField("设置窗口");
+    this.appendDummyInput()
+        .appendField("全屏显示");
+    this.setInputsInline(true);
+    this.setPreviousStatement(true, null);
+    this.setNextStatement(true, null);
+    this.setStyle('OpenCV_blocks');
+    this.setTooltip("设置显示图像的窗口全屏显示,须在创建窗口前设置才能生效");
+    this.setHelpUrl("");
+    }
+  };
